@@ -2,7 +2,7 @@ from models import Page
 import factory
 import random
 
-class PageFactory(factory.Factory):
+class PageFactory(factory.DjangoModelFactory):
     FACTORY_FOR = Page
 
     graph_id = factory.Sequence(lambda n: n)
\ No newline at end of file
